@@ -1,3 +1,4 @@
+pub mod anchor_base;
 pub mod anchor_handler;
 pub mod anchor_proxy;
 pub mod fixed_deposit_anchor;
@@ -8,6 +9,7 @@ pub mod treasury;
 pub mod treasury_handler;
 pub mod variable_anchor;
 
+pub use anchor_base::*;
 pub use anchor_handler::*;
 pub use anchor_proxy::*;
 pub use fixed_deposit_anchor::*;
